@@ -80,7 +80,7 @@ fn is_even(n: u128) -> bool {
 }
 
 /// Returns true if n is odd and false if n is even.
-fn is_even_any(n: &dyn ToString) -> bool {
+pub fn is_even_any(n: &dyn ToString) -> bool {
     is_even(n.to_string().parse::<u128>().unwrap())
 }
 
